#delimit;

set linesize 140;
set mem 200m;

*************************************************************************************************************;

*************************************************************************************************************;

*** 1. Generate Table 2, Row 4 ******************************************************************************;
*************************************************************************************************************;

*************************************************************************************************************;

*** 1a: Generate local variables ****************************************************************************;


use DG_CORRECTED_SAMPLE_2012;

table year [aw=fland], c(mean y count y);
table year [aw=fland], c(mean dd89 count dd89 mean prcp count prcp);

summ dd89 [aw=fland];
local m_dd89=r(mean);
summ prcp [aw=fland];
local m_prcp=r(mean);

save MASTER, replace;
clear;


*************************************************************************************************************;

*************************************************************************************************************;

*** 1b. Weather variable regressions (with county-clustered and state-clustered SEs) ************************;

*************************************************************************************************************;

*** 1bi. Specification A: With year effects *****************************************************************;

use MASTER;



* County-clustered SEs;
xi: areg y dd89 dd89_sq prcp prcp_sq i.year x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store YYYY;


* State-clustered SEs;
quiet xi: areg y dd89 dd89_sq prcp prcp_sq i.year x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store YYYY_cluster_state;


*************************************************************************************************************;

*** 1bii. Specification B: With USDA-region specific year effects *******************************************;


* County-clustered SEs;
xi: areg y dd89 dd89_sq prcp prcp_sq i.uuyy x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store UUYY;


* State-clustered SEs;
quiet xi: areg y dd89 dd89_sq prcp prcp_sq i.uuyy x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store UUYY_cluster_state;


*************************************************************************************************************;

*** 1biii. Specification C: With Census-division specific year effects **************************************;


* County-clustered SEs;
xi: areg y dd89 dd89_sq prcp prcp_sq i.ddyy x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store DDYY;


* State-clustered SEs;
quiet xi: areg y dd89 dd89_sq prcp prcp_sq i.ddyy x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store DDYY_cluster_state;


*************************************************************************************************************;

*** 1biv. Specification D: With state specific year effects *************************************************;


* County-clustered SEs;
xi: areg y dd89 dd89_sq prcp prcp_sq i.ssyy x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store SSYY;


* State-clustered SEs;
quiet xi: areg y dd89 dd89_sq prcp prcp_sq i.ssyy x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store SSYY_cluster_state;
clear;

*************************************************************************************************************;

*************************************************************************************************************;

*** 1c. Reweighted predicted change in climate **************************************************************;

use MASTER;                  

egen sb_=sum(fland*h2_d_dd89/1000000000), by(year);
summ sb_;
local d_h2_dd89=r(mean);
drop sb_;

egen sb_=sum(fland*h2_d_dd89_sq/1000000000), by(year);
summ sb_;
local d_h2_dd89_sq=r(mean);
drop sb_;

egen sb_=sum(fland*h2_d_prcp/1000000000), by(year); 
summ sb_;
local d_h2_prcp=r(mean);
drop sb_;                    

egen sb_=sum(fland*h2_d_prcp_sq/1000000000), by(year);
summ sb_;                    
local d_h2_prcp_sq=r(mean);  
drop sb_;          



*************************************************************************************************************;

*************************************************************************************************************;

*** 1d. Predicted Impact on Aggregate Farm Profits **********************************************************;

***		Notes: $2002 BIL.  See di statement for panel / row / column information ****************************;

*** 	First reported estimate has county-clustered std error **********************************************;

*** 	Second reported estimate has state-clustered std error **********************************************;

***		All estimates are derived under the Hadley 2 climate model ******************************************;

*************************************************************************************************************;



*************************************************************************************************************;

*** 1di. Table 2, Row 4, Column 1a **************************************************************************;


di "*********************************************************************";
di "*********************************************************************";
di "Table 2, Row 4, Column 1a";
estimates restore YYYY;
lincom _b[dd89]*`d_h2_dd89' + _b[dd89_sq]*`d_h2_dd89_sq' + _b[prcp]*`d_h2_prcp' + _b[prcp_sq]*`d_h2_prcp_sq' ;
gen pp_1a=r(estimate);
gen secc_1a=r(se);

estimates restore YYYY_cluster_state;
lincom _b[dd89]*`d_h2_dd89' + _b[dd89_sq]*`d_h2_dd89_sq' + _b[prcp]*`d_h2_prcp' + _b[prcp_sq]*`d_h2_prcp_sq' ;
gen sesc_1a=r(se);


*************************************************************************************************************;

*** 1dii. Table 2, Row 4, Column 1b *************************************************************************;


di "*********************************************************************";
di "*********************************************************************";
di "Table 2, Row 4, Column 1b";
estimates restore UUYY;
lincom _b[dd89]*`d_h2_dd89' + _b[dd89_sq]*`d_h2_dd89_sq' + _b[prcp]*`d_h2_prcp' + _b[prcp_sq]*`d_h2_prcp_sq' ;
gen pp_1b=r(estimate);
gen secc_1b=r(se);

estimates restore UUYY_cluster_state;
lincom _b[dd89]*`d_h2_dd89' + _b[dd89_sq]*`d_h2_dd89_sq' + _b[prcp]*`d_h2_prcp' + _b[prcp_sq]*`d_h2_prcp_sq' ;
gen sesc_1b=r(se);


*************************************************************************************************************;

*** 1diii. Table 2, Row 4, Column 1c ************************************************************************;


di "*********************************************************************";
di "*********************************************************************";
di "Table 2, Row 4, Column 1c";
estimates restore DDYY;
lincom _b[dd89]*`d_h2_dd89' + _b[dd89_sq]*`d_h2_dd89_sq' + _b[prcp]*`d_h2_prcp' + _b[prcp_sq]*`d_h2_prcp_sq' ;
gen pp_1c=r(estimate);
gen secc_1c=r(se);

estimates restore DDYY_cluster_state;
lincom _b[dd89]*`d_h2_dd89' + _b[dd89_sq]*`d_h2_dd89_sq' + _b[prcp]*`d_h2_prcp' + _b[prcp_sq]*`d_h2_prcp_sq' ;
gen sesc_1c=r(se);


*************************************************************************************************************;

*** 1div. Table 2, Row 4, Column 1d *************************************************************************;


di "*********************************************************************";
di "*********************************************************************";
di "Table 2, Row 4, Column 1d";
estimates restore SSYY;
lincom _b[dd89]*`d_h2_dd89' + _b[dd89_sq]*`d_h2_dd89_sq' + _b[prcp]*`d_h2_prcp' + _b[prcp_sq]*`d_h2_prcp_sq' ;
gen pp_1d=r(estimate);
gen secc_1d=r(se);

estimates restore SSYY_cluster_state;
lincom _b[dd89]*`d_h2_dd89' + _b[dd89_sq]*`d_h2_dd89_sq' + _b[prcp]*`d_h2_prcp' + _b[prcp_sq]*`d_h2_prcp_sq' ;
gen sesc_1d=r(se);


*************************************************************************************************************;



* Summary Table: Estimates, specifications a-d;
summ pp*, sep(0);

* Summary Table: County-clustered SEs, spec. a-d;
summ secc*, sep(0);

* Summary Table: State-clustered SEs, spec. a-d;
summ sesc*, sep(0);

clear;

! \rm MASTER.dta;
! \rm *.o*;

