#delimit;

set mem 200m;
set linesize 140;

*************************************************************************************************************;
*************************************************************************************************************;
*** 1a. Weather variable regressions (with county-clustered and state-clustered SEs) ************************;

use DG_CORRECTED_SAMPLE_2012;

table year [aw=fland], c(mean y count y);
table year [aw=fland], c(mean dd89 count dd89 mean prcp count prcp);

gen L1_dd89_sq=L1_dd89*L1_dd89;
gen L1_prcp=L1_totprcp;
gen L1_prcp_sq=L1_prcp*L1_prcp;

save MASTER, replace;
clear;


*************************************************************************************************************;

*** 1ai. Specification A: With year effects *****************************************************************;

use MASTER;
* County-clustered SEs;
xi: areg y dry dd89 dd89_sq L1_dd89 L1_dd89_sq prcp prcp_sq L1_prcp L1_prcp_sq i.year x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store YYYY;
testparm dd89*;
testparm L1_dd89*;
testparm dd89* L1_dd89*;
testparm prcp*;
testparm L1_prcp*;
testparm prcp* L1_prcp*;
testparm _Iyear*;

* State-clustered SEs;
quiet xi: areg y dry dd89 dd89_sq L1_dd89 L1_dd89_sq prcp prcp_sq L1_prcp L1_prcp_sq i.year x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store YYYY_cluster_state;
clear;


*************************************************************************************************************;

*** 1aii. Specification B: With USDA-region specific year effects *******************************************;

use MASTER;
* County-clustered SEs;
xi: areg y dry dd89 dd89_sq L1_dd89 L1_dd89_sq prcp prcp_sq L1_prcp L1_prcp_sq i.uuyy x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store UUYY;
testparm dd89*;
testparm L1_dd89*;
testparm dd89* L1_dd89*;
testparm prcp*;
testparm L1_prcp*;
testparm prcp* L1_prcp*;
testparm _Iuuyy*;

* State-clustered SEs;
quiet xi: areg y dry dd89 dd89_sq L1_dd89 L1_dd89_sq prcp prcp_sq L1_prcp L1_prcp_sq i.uuyy x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store UUYY_cluster_state;
clear;


*************************************************************************************************************;

*** 1aiii. Specification C: With Census-division specific year effects **************************************;

use MASTER;
* County-clustered SEs;
xi: areg y dry dd89 dd89_sq L1_dd89 L1_dd89_sq prcp prcp_sq L1_prcp L1_prcp_sq i.ddyy x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store DDYY;
testparm dd89*;
testparm L1_dd89*;
testparm dd89* L1_dd89*;
testparm prcp*;
testparm L1_prcp*;
testparm prcp* L1_prcp*;
testparm _Iddyy*;

* State-clustered SEs;
quiet xi: areg y dry dd89 dd89_sq L1_dd89 L1_dd89_sq prcp prcp_sq L1_prcp L1_prcp_sq i.ddyy x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store DDYY_cluster_state;
clear;


*************************************************************************************************************;

*** 1aiv. Specification D: With state specific year effects *************************************************;

use MASTER;
* County-clustered SEs;
xi: areg y dry dd89 dd89_sq L1_dd89 L1_dd89_sq prcp prcp_sq L1_prcp L1_prcp_sq i.ssyy x1-x9 [aweight=fland], a(fips) cluster(fips);
estimates store SSYY;
testparm dd89*;
testparm L1_dd89*;
testparm dd89* L1_dd89*;
testparm prcp*;
testparm L1_prcp*;
testparm prcp* L1_prcp*;
testparm _Issyy*;

* State-clustered SEs;
quiet xi: areg y dry dd89 dd89_sq L1_dd89 L1_dd89_sq prcp prcp_sq L1_prcp L1_prcp_sq i.ssyy x1-x9 [aweight=fland], a(fips) cluster(statefips);
estimates store SSYY_cluster_state;
clear;


*************************************************************************************************************;

*************************************************************************************************************;

*** 1b. Reweighted predicted change in climate **************************************************************;

use MASTER;                  

egen sb_=sum(fland*ccsm_d_dd89/1000000000), by(year);
summ sb_;
local d_ccsm_dd89=r(mean);
drop sb_;

egen sb_=sum(fland*ccsm_d_dd89_sq/1000000000), by(year);
summ sb_;
local d_ccsm_dd89_sq=r(mean);
drop sb_;

egen sb_=sum(fland*ccsm_d_prcp/1000000000), by(year); 
summ sb_;
local d_ccsm_prcp=r(mean);
drop sb_;                    

egen sb_=sum(fland*ccsm_d_prcp_sq/1000000000), by(year);
summ sb_;                    
local d_ccsm_prcp_sq=r(mean);  
drop sb_;          


*************************************************************************************************************;

*************************************************************************************************************;

*** 1c. Calculate Average Annual Aggregate Farm Profits *****************************************************;

gen pi = y*fland;
bys year (fips): egen agg_pi = total(pi);
egen avg_agg_pi = mean(agg_pi);
label var avg_agg_pi "Average annual aggregate farm profits in sample";

*************************************************************************************************************;

*************************************************************************************************************;

*** 1d. Predicted Impact on Aggregate Farm Profits **********************************************************;

*** Notes: $2002 BIL.  See di statement for panel / row / column information ****************************;

*** "secc" denotes county-clustered standard errors *****************************************************;

*** "secs" denotes state-clustered standard errors ******************************************************;

*** All estimates are derived under the CCSM 3 A2 climate model *****************************************;

*************************************************************************************************************;

*************************************************************************************************************;

*** 1di. Table 3, Panel B, Row 2, Column 1a *****************************************************************;

di "CCSM 3 A2, Spec 1a";
estimates restore YYYY;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' +
       _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_1a=r(estimate);
gen ccsm_secc_1a=r(se);
gen perc_1a=r(estimate)*100000000000/avg_agg_pi;

lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_0_1a=r(estimate);
gen ccsm_0_secc_1a=r(se);

lincom _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_1_1a=r(estimate);
gen ccsm_1_secc_1a=r(se);

estimates restore YYYY_cluster_state;
quiet lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' +
             _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_secs_1a=r(se);

*************************************************************************************************************;

*** 1dii. Table 3, Panel B, Row 2, Column 1b ****************************************************************;

di "CCSM 3 A2, Spec 1b";
estimates restore UUYY;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' +
       _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_1b=r(estimate);
gen ccsm_secc_1b=r(se);
gen perc_1b=r(estimate)*100000000000/avg_agg_pi;

lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_0_1b=r(estimate);
gen ccsm_0_secc_1b=r(se);

lincom _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_1_1b=r(estimate);
gen ccsm_1_secc_1b=r(se);

estimates restore UUYY_cluster_state;
quiet lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' +
             _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_secs_1b=r(se);

*************************************************************************************************************;

*** 1diii. Table 3, Panel B, Row 2, Column 1c ***************************************************************;

di "CCSM 3 A2, Spec 1c";
estimates restore DDYY;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' +
       _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_1c=r(estimate);
gen ccsm_secc_1c=r(se);
gen perc_1c=r(estimate)*100000000000/avg_agg_pi;

lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_0_1c=r(estimate);
gen ccsm_0_secc_1c=r(se);

lincom _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_1_1c=r(estimate);
gen ccsm_1_secc_1c=r(se);

estimates restore DDYY_cluster_state;
quiet lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' +
             _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_secs_1c=r(se);

*************************************************************************************************************;

*** 1div. Table 3, Panel B, Row 2, Column 1d ****************************************************************;

di "CCSM 3 A2, Spec 1d";
estimates restore SSYY;
lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' +
       _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_1d=r(estimate);
gen ccsm_secc_1d=r(se);
gen perc_1d=r(estimate)*100000000000/avg_agg_pi;

lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_0_1d=r(estimate);
gen ccsm_0_secc_1d=r(se);

lincom _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_1_1d=r(estimate);
gen ccsm_1_secc_1d=r(se);

estimates restore SSYY_cluster_state;
quiet lincom _b[dd89]*`d_ccsm_dd89' + _b[dd89_sq]*`d_ccsm_dd89_sq' + _b[prcp]*`d_ccsm_prcp' + _b[prcp_sq]*`d_ccsm_prcp_sq' +
             _b[L1_dd89]*`d_ccsm_dd89' + _b[L1_dd89_sq]*`d_ccsm_dd89_sq' + _b[L1_prcp]*`d_ccsm_prcp' + _b[L1_prcp_sq]*`d_ccsm_prcp_sq';
gen ccsm_secs_1d=r(se);

*************************************************************************************************************;


* Summary Table: Estimates, specifications a-d;
di "Table 3, CCSM 3 A2 2070-2099, Column 1a, Contemporaneous Weather Impact"; 
summ ccsm_0_1a ccsm_0_secc_1a;
di "Table 3, CCSM 3 A2 2070-2099, Column 1a, Lagged Weather Impact"; 
summ ccsm_1_1a ccsm_1_secc_1a;
di "Table 3, CCSM 3 A2 2070-2099, Column 1a, Overall Impact"; 
summ ccsm_1a ccsm_secc_1a ccsm_secs_1a;

di "Table 3, CCSM 3 A2 2070-2099, Column 1b, Contemporaneous Weather Impact"; 
summ ccsm_0_1b ccsm_0_secc_1b;
di "Table 3, CCSM 3 A2 2070-2099, Column 1b, Lagged Weather Impact"; 
summ ccsm_1_1b ccsm_1_secc_1b;
di "Table 3, CCSM 3 A2 2070-2099, Column 1b, Overall Impact"; 
summ ccsm_1b ccsm_secc_1b ccsm_secs_1b;

di "Table 3, CCSM 3 A2 2070-2099, Column 1c, Contemporaneous Weather Impact"; 
summ ccsm_0_1c ccsm_0_secc_1c;
di "Table 3, CCSM 3 A2 2070-2099, Column 1c, Lagged Weather Impact"; 
summ ccsm_1_1c ccsm_1_secc_1c;
di "Table 3, CCSM 3 A2 2070-2099, Column 1c, Overall Impact"; 
summ ccsm_1c ccsm_secc_1c ccsm_secs_1c;

di "Table 3, CCSM 3 A2 2070-2099, Column 1d, Contemporaneous Weather Impact"; 
summ ccsm_0_1d ccsm_0_secc_1d;
di "Table 3, CCSM 3 A2 2070-2099, Column 1d, Lagged Weather Impact"; 
summ ccsm_1_1d ccsm_1_secc_1d;
di "Table 3, CCSM 3 A2 2070-2099, Column 1d, Overall Impact"; 
summ ccsm_1d ccsm_secc_1d ccsm_secs_1d;

di "Table 3, Panel B, Row 2, Percent Impact";
summ perc*, sep(0);
drop perc*;

clear;

! \rm *.o*;
! \rm MASTER.dta;

